<?php

namespace Drupal\migrate_sandbox\Plugin\migrate\destination;

use Drupal\migrate\Exception\EntityValidationException;
use Drupal\migrate\MigrateException;
use Drupal\migrate\Row;

/**
 * Provides destination for content entity that we don't save.
 */
class MigrateSandboxEntityContentBase extends MigrateSandboxEntity {

  /**
   * {@inheritdoc}
   */
  public function import(Row $row, array $old_destination_id_values = []) {
    if ($bundle = $this->getBundle($row)) {
      $row->setDestinationProperty($this->getKey('bundle'), $bundle);
    }
    $entity = $this->storage->create($row->getDestination());
    if (!$entity) {
      throw new MigrateException('Unable to create sandbox entity');
    }
    \Drupal::service('tempstore.private')->get('migrate_sandbox')->set('migrate_sandbox.latest', $entity);
    $violations = $entity->validate();
    if (count($violations) > 0) {
      throw new EntityValidationException($violations);
    }
    $entity->delete();
    return TRUE;
  }

  /**
   * {@inheritdoc}
   */
  public function getIds() {
    return [];
  }

}
